@@ -1,4 +1,7 @@
 import json
+
+import redis
+
 from other.common.file.io import remove_if_exists, write_file
 
 import mysql.connector
@@ -7,7 +10,7 @@ _HOST = 'localhost'
 _PORT = '3311'
 _USER = 'ucode'
 _PASSWORD = 'ucode1234'
-_DATABASE = 'ucode'
+_DATABASE = 'ucode_19_02'
 
 
 def get_ucode_user_token():
@@ -21,9 +24,7 @@ def get_ucode_user_token():
     mycursor = mydb.cursor(dictionary=True)
     mycursor.execute(
         '''
-        select t.token from user_token t 
-        RIGHT JOIN user u on t.user_id = u.id
-        where t.expired_at > NOW() and type='student' and u.is_deleted=0 and t.is_deleted=0
+select user_id, token from user_token where id in (select max(id) from user_token where expired_at > now() and is_deleted = 0 group by user_id) limit 1000
         '''
     )
     users = mycursor.fetchall()
@@ -33,4 +34,9 @@ def get_ucode_user_token():
                'UCODE_STUDENT_USER_TOKEN = ' + json.dumps(tokens, indent=2))
     mycursor.close()
     mydb.close()
+    redisClient = redis.StrictRedis(host='localhost',
+                                    port=6379,
+                                    db=0)
+    key = 'tokens'
+    redisClient.lpush(key, *tokens)
     return tokens
