@@ -15,43 +15,7 @@ from ucode.helpers.clog import CLog
 from ucode.helpers.misc import make_problem_code, join_lines, findfiles
 from ucode.models.problem import Problem, TestCase, ProblemFolderFormat
 from ucode.services.common import find_section
-
-
-def read_ucode_testcases_from_file(testcase_file):
-    count = 0
-    inputi = ""
-    outputi = ""
-    is_output = False
-
-    testcases = []
-    name = ""
-    with open(testcase_file, 'r', encoding="utf-8") as fi:
-        for line in fi:
-            if line.startswith("###"):
-
-                if count > 0:
-                    testcases.append({'input': inputi.rstrip(), 'output': outputi.rstrip(), 'name': name})
-
-                name = line[3:].strip()
-                # print("N:", name)
-                count += 1
-
-                is_output = False
-
-                inputi = outputi = ""
-
-                continue
-            elif line.startswith("---"):
-                is_output = True
-            else:
-                if is_output:
-                    outputi += line
-                else:
-                    inputi += line
-        if inputi.rstrip() or outputi.rstrip():
-            testcases.append({'input': inputi.rstrip(), 'output': outputi.rstrip(), 'name': name})
-
-    return testcases
+from ucode.services.testcase.testcase_service import TestcaseService
 
 
 def fix_section_title(name, pattern, lines, replace, once=True):
@@ -447,12 +411,13 @@ class ProblemService:
             CLog.warn(f"Testcase input generator file is missing!")
         if not os.path.isfile(problem_files['editorial']):
             CLog.warn(f"Editorial file `{problem_files['editorial']}` is missing!")
-        if not os.path.isfile(problem_files['testcases']):
-            CLog.error(f"Testcases file `{problem_files['testcases']}` is missing!")
-        else:
-            file_size = os.stat(problem_files['testcases']).st_size
-            if file_size > 50 * 1024 * 1024:
-                CLog.error(f"Testcases file `{problem_files['testcases']}` should not be > 50MB!")
+        if metadata['testcase_format'] != ProblemFolderFormat.themis.value:
+            if not os.path.isfile(problem_files['testcases']):
+                CLog.error(f"Testcases file `{problem_files['testcases']}` is missing!")
+            else:
+                file_size = os.stat(problem_files['testcases']).st_size
+                if file_size > 50 * 1024 * 1024:
+                    CLog.error(f"Testcases file `{problem_files['testcases']}` should not be > 50MB!")
 
         if not os.path.isfile(problem_files['testcases_sample']):
             CLog.warn(f"Sample testcases file `{problem_files['testcases_sample']}` is missing!")
@@ -540,7 +505,7 @@ class ProblemService:
                   encoding="utf-8") as f:
             problem.editorial = Template(f.read()).render(problem=problem)
 
-        ProblemService._parse_statement_file(os.path.join(template_path, f"{prefix_path}statement.md"), problem)
+        ProblemService.parse_statement_file(os.path.join(template_path, f"{prefix_path}statement.md"), problem)
         problem.name = problem_name
         problem.code = problem_code
 
@@ -567,7 +532,7 @@ class ProblemService:
         CLog.important(f'Problem created at `{folder}`')
 
     @staticmethod
-    def _parse_statement_file(statement_file, problem: Problem):
+    def parse_statement_file(statement_file, problem: Problem):
         with open(statement_file, encoding="utf-8") as fi:
             statement = fi.read()
             lines = statement.splitlines()
@@ -606,9 +571,9 @@ class ProblemService:
                 for i in range(len(sample_input_i)):
                     testcase = TestCase()
                     _input = join_lines(sample_input_c[sample_input_i[i]]).strip('`').lstrip("\n").rstrip()
-                    print(f"**** i `{_input}`")
+                    # print(f"**** i `{_input}`")
                     _output = join_lines(sample_output_c[sample_output_i[i]]).strip('`').lstrip("\n").rstrip()
-                    print(f"**** o `{_output}`")
+                    # print(f"**** o `{_output}`")
                     testcase.input = _input
                     testcase.output = _output
                     if len(explanation_i) > i:
@@ -747,13 +712,13 @@ class ProblemService:
 
             if os.path.exists(problem_files["editorial"]):
                 editorial_prob = Problem()
-                ProblemService._parse_statement_file(problem_files["editorial"], editorial_prob)
+                ProblemService.parse_statement_file(problem_files["editorial"], editorial_prob)
                 if editorial_prob.statement.strip():
                     problem.editorial = editorial_prob.statement
 
             ProblemService._get_problem_resource_files(problem_folder, problem)
 
-            ProblemService._parse_statement_file(problem_files["statement"], problem)
+            ProblemService.parse_statement_file(problem_files["statement"], problem)
             if meta.get("statement_translations"):
                 for lang in meta["statement_translations"]:
                     lang_statement_file = os.path.join(problem_folder, problem_files['translation'] % lang)
@@ -761,7 +726,7 @@ class ProblemService:
                         CLog.warn(f"Translation file not existed: {lang_statement_file}")
                     else:
                         tran_problem = copy.copy(problem)
-                        ProblemService._parse_statement_file(lang_statement_file, tran_problem)
+                        ProblemService.parse_statement_file(lang_statement_file, tran_problem)
                         problem.translations[lang] = tran_problem
 
             # if os.path.exists(problem_files['stock_solution']):
@@ -880,7 +845,7 @@ class ProblemService:
                     CLog.warn(f'`{testcase_file}` file not existed, skipping...')
                 else:
                     CLog.info(f'`{testcase_file}` file FOUND, reading testcases...')
-                    tests = read_ucode_testcases_from_file(testcase_file)
+                    tests = TestcaseService.load_testcases(testcase_file, format='ucode')
                     # print(f"reading testcases in file {testcase_file}: {len(tests)}")
                     for t in tests:
                         _input, _output = t['input'], t['output']
@@ -900,7 +865,7 @@ class ProblemService:
 
     @staticmethod
     def convert(problem_folder: str, _from: ProblemFolderFormat, _to: ProblemFolderFormat,
-                output: str, overwrite: bool = False, convert_testcases_only=False):
+                output: str=None, overwrite: bool = False, convert_testcases_only=False):
         if _to != ProblemFolderFormat.ucode:
             CLog.error("Current support converting to 'ucode' format only")
             return
@@ -1087,6 +1052,8 @@ class ProblemService:
             ProblemService.load_ucode_testcases(problem_folder, problem)
         elif format == ProblemFolderFormat.themis.value:
             ProblemService.load_themis_testcases(problem_folder, problem)
+        elif format == ProblemFolderFormat.cms.value:
+            ProblemService.load_cms_testcases(problem_folder, problem)
         else:
             CLog.error(f"Unknown testcase format {format}")
 
@@ -1102,7 +1069,7 @@ class ProblemService:
             if not os.path.exists(testcase_file) or not os.path.isfile(testcase_file):
                 CLog.info(f'`{testcase_file}` file not existed, skipping...')
             else:
-                tests = read_ucode_testcases_from_file(testcase_file)
+                tests = TestcaseService.load_testcases(testcase_file, format='ucode')
                 print(f"reading testcases in file {testcase_file}: {len(tests)}")
                 for t in tests:
                     _input, _output, _name = t['input'], t['output'], t['name']
@@ -1120,30 +1087,11 @@ class ProblemService:
 
     @staticmethod
     def load_themis_testcases(problem_folder, problem: Problem):
-        problem.testcases = []
-        test_folders = glob.glob(os.path.join(problem_folder, "Test*"))
-        for test_folder in test_folders:
-            # test_folder = os.path.abspath(test_folder)
-            if not os.path.isdir(test_folder):
-                continue
-            # print(test_folder)
+        problem.testcases = TestcaseService.load_testcases(problem_folder, format='themis')
 
-            input_files = findfiles("*.INP", test_folder)
-            output_files = findfiles("*.OUT", test_folder)
-            # print(input_files, len(input_files))
-            # print(output_files, len(output_files))
-            if len(input_files) != 1 or len(output_files) != 1:
-                CLog.error(f"Invalid testcase folder `{os.path.abspath(test_folder)}`")
-                continue
-            input_file = input_files[0]
-            output_file = output_files[0]
-
-            print(input_file, output_file)
-            with open(input_file, 'r') as fi:
-                _input = fi.read()
-            with open(output_file, 'r') as fo:
-                _output = fo.read()
-            problem.testcases.append(TestCase(input=_input, output=_output))
+    @staticmethod
+    def load_cms_testcases(problem_folder, problem: Problem):
+        problem.testcases = TestcaseService.load_testcases(os.path.join(problem_folder, "testcases.zip"), format='cms')
 
     @staticmethod
     def join_testcases(problem: Problem):
@@ -1159,7 +1107,7 @@ class ProblemService:
 
 
 def convert_all_v1_to_new_format(src_folder, dest_folder=None, translations=[]):
-    # problems = ProblemService.read_all_problems_v1(base_folder)
+    # problems = ProblemService.read_all_problems_v1(src_folder)
     problems = ProblemService.read_all_problems_v1(src_folder, load_testcase=True, translations=translations)
 
     if not dest_folder:
@@ -1196,8 +1144,11 @@ if __name__ == "__main__":
     # change_testcases()
     # base_folder = "D:\\projects\\ucode\\dsa-problems\\competitions\\hsg_thcs\\Thuc\\HaNoi2019"
     # base_folder = "D:\\projects\\ucode\\basic_problems\\hour-of-code-round2\\old"
-    base_folder = "D:\\projects\\ucode\\basic_problems\\hour-of-code-round3\\_old"
-
+    # base_folder = "D:\\projects\\ucode\\basic_problems\\hour-of-code-round3\\_old"
+    # base_folder = "D:\\projects\\ucode\\dsa-thematic-problems\\competitive_programing_topics\\maths\\fundamentals\\gcd_lcm_new\\number_game"
+    # ProblemService.convert(base_folder, ProblemFolderFormat.themis, ProblemFolderFormat.ucode,
+    #                        convert_testcases_only=True, overwrite=True)
+    base_folder = r"D:\projects\ucode\weekly-algorithm-problems\competitions\teko-hcm\old"
     convert_all_v1_to_new_format(base_folder)
     # DsaProblem.create_problem('../../problems', 'Counting Sort 3', lang="en",
     #                           translations=['vi', 'ru'],
